@@ -18,7 +18,7 @@ To use::
     :top-classes: collections.UserList
     :parts: 1
     
-.. image:: figs/pose-values.png
+.. image:: ../figs/pose-values.png
 """
 from __future__ import annotations
 
@@ -286,14 +286,11 @@ class SO3(BasePoseMatrix):
 
         :param unit: angular units: 'rad' [default], or 'deg'
         :type unit: str
-        :param check: check that rotation matrix is valid
-        :type check: bool
-        :return: :math:`(\theta, {\bf v})`
+        :return: :math:`(\theta, \hat{\bf v})`
         :rtype: float or ndarray(3)
 
-        ``q.angvec()`` is a tuple :math:`(\theta, v)` containing the rotation
-        angle and a rotation axis which is equivalent to the rotation of
-        the unit quaternion ``q``.
+        ``x.angvec()`` is a tuple :math:`(\theta, v)` containing the rotation
+        angle and a rotation axis.
 
         By default the angle is in radians but can be changed setting `unit='deg'`.
 
@@ -305,13 +302,42 @@ class SO3(BasePoseMatrix):
 
         .. runblock:: pycon
 
-            >>> from spatialmath import UnitQuaternion
-            >>> UnitQuaternion.Rz(0.3).angvec()
+            >>> from spatialmath import SO3
+            >>> R = SO3.Rx(0.3)
+            >>> R.angvec()
 
-        :seealso: :func:`~spatialmath.quaternion.AngVec`, :func:`~angvec2r`
+        :seealso: :meth:`eulervec` :meth:`AngVec` :meth:`~spatialmath.quaternion.UnitQuaternion.angvec` :meth:`~spatialmath.quaternion.AngVec`, :func:`~angvec2r`
         """
         return smb.tr2angvec(self.R, unit=unit)
 
+    def eulervec(self) -> R3:
+        r"""
+        SO(3) or SE(3) as Euler vector (exponential coordinates)
+
+        :return: :math:`\theta \hat{\bf v}`
+        :rtype: ndarray(3)
+
+        ``x.eulervec()`` is the Euler vector (or exponential coordinates) which
+        is related to angle-axis notation and is the product of the rotation
+        angle and the rotation axis.
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> from spatialmath import SO3
+            >>> R = SO3.Rx(0.3)
+            >>> R.eulervec()
+
+        .. note::
+
+            - If the input is SE(3) the translation component is ignored.
+
+        :seealso: :meth:`angvec` :func:`~angvec2r`
+        """
+        theta, v = smb.tr2angvec(self.R)
+        return theta * v
+    
     # ------------------------------------------------------------------------ #
 
     @staticmethod
@@ -765,6 +791,7 @@ class SO3(BasePoseMatrix):
         :param S: Lie algebra so(3)
         :type S: ndarray(3,3), ndarray(n,3)
         :param check: check that passed matrix is valid so(3), default True
+        :bool check: bool, optional
         :param so3: the input is interpretted as an so(3) matrix not a stack of three twists, default True
         :return: SO(3) rotation
         :rtype: SO3 instance
@@ -1093,7 +1120,7 @@ class SE3(SO3):
 
         If spatial velocity :math:`\nu = (v_x, v_y, v_z, \omega_x, \omega_y, \omega_z)^T`
         and the SE(3) represents the pose of {B} relative to {A},
-        ie. :math:`{}^A {\bf T}_B, and the adjoint is :math:`\mathbf{A}` then
+        ie. :math:`{}^A {\bf T}_B`, and the adjoint is :math:`\mathbf{A}` then
         :math:`{}^{A}\!\nu = \mathbf{A} {}^{B}\!\nu`.
 
         .. warning:: Do not use this method to map velocities
