@@ -18,7 +18,7 @@ from __future__ import annotations
 import math
 import numpy as np
 from typing import Any, Type
-from spatialmath import base
+import spatialmath.base as smb
 from spatialmath.pose3d import SO3, SE3
 from spatialmath.baseposelist import BasePoseList
 from spatialmath.base.types import *
@@ -82,12 +82,12 @@ class Quaternion(BasePoseList):
             if super().arghandler(s, check=False):
                 return
 
-            elif base.isvector(s, 4):
-                self.data = [base.getvector(s)]
+            elif smb.isvector(s, 4):
+                self.data = [smb.getvector(s)]
 
-        elif base.isscalar(s) and base.isvector(v, 3):
+        elif smb.isscalar(s) and smb.isvector(v, 3):
             # Quaternion(s, v)
-            self.data = [np.r_[s, base.getvector(v)]]
+            self.data = [np.r_[s, smb.getvector(v)]]
 
         else:
             raise ValueError("bad argument to Quaternion constructor")
@@ -111,7 +111,7 @@ class Quaternion(BasePoseList):
             >>> from spatialmath import Quaternion
             >>> print(Quaternion.Pure([1,2,3]))
         """
-        return cls(s=0, v=base.getvector(v, 3))
+        return cls(s=0, v=smb.getvector(v, 3))
 
     @staticmethod
     def _identity():
@@ -286,7 +286,7 @@ class Quaternion(BasePoseList):
         :seealso: :func:`~spatialmath.base.quaternions.qmatrix`
         """
 
-        return base.qmatrix(self._A)
+        return smb.qmatrix(self._A)
 
     def conj(self) -> Quaternion:
         r"""
@@ -307,7 +307,7 @@ class Quaternion(BasePoseList):
         :seealso: :func:`~spatialmath.base.quaternions.qconj`
         """
 
-        return self.__class__([base.qconj(q._A) for q in self])
+        return self.__class__([smb.qconj(q._A) for q in self])
 
     def norm(self) -> float:
         r"""
@@ -330,9 +330,9 @@ class Quaternion(BasePoseList):
         :seealso: :func:`~spatialmath.base.quaternions.qnorm`
         """
         if len(self) == 1:
-            return base.qnorm(self._A)
+            return smb.qnorm(self._A)
         else:
-            return np.array([base.qnorm(q._A) for q in self])
+            return np.array([smb.qnorm(q._A) for q in self])
 
     def unit(self) -> UnitQuaternion:
         r"""
@@ -358,7 +358,7 @@ class Quaternion(BasePoseList):
 
         :seealso: :func:`~spatialmath.base.quaternions.qnorm`
         """
-        return UnitQuaternion([base.qunit(q._A) for q in self], norm=False)
+        return UnitQuaternion([smb.qunit(q._A) for q in self], norm=False)
 
     def log(self) -> Quaternion:
         r"""
@@ -393,7 +393,7 @@ class Quaternion(BasePoseList):
         """
         norm = self.norm()
         s = math.log(norm)
-        v = math.acos(self.s / norm) * base.unitvec(self.v)
+        v = math.acos(self.s / norm) * smb.unitvec(self.v)
         return Quaternion(s=s, v=v)
 
     def exp(self) -> Quaternion:
@@ -430,7 +430,7 @@ class Quaternion(BasePoseList):
         :seealso: :meth:`Quaternion.log` :meth:`UnitQuaternion.log` :meth:`UnitQuaternion.AngVec` :meth:`UnitQuaternion.EulerVec`
         """
         exp_s = math.exp(self.s)
-        norm_v = base.norm(self.v)
+        norm_v = smb.norm(self.v)
         s = exp_s * math.cos(norm_v)
         v = exp_s * self.v / norm_v * math.sin(norm_v)
         if abs(self.s) < 100 * _eps:
@@ -463,7 +463,7 @@ class Quaternion(BasePoseList):
         assert isinstance(
             other, Quaternion
         ), "operands to inner must be Quaternion subclass"
-        return self.binop(other, base.qinner, list1=False)
+        return self.binop(other, smb.qinner, list1=False)
 
     # -------------------------------------------- operators
 
@@ -493,7 +493,7 @@ class Quaternion(BasePoseList):
         :seealso: :func:`__ne__` :func:`~spatialmath.base.quaternions.qisequal`
         """
         assert isinstance(left, type(right)), "operands to == are of different types"
-        return left.binop(right, base.qisequal, list1=False)
+        return left.binop(right, smb.qisequal, list1=False)
 
     def __ne__(
         left, right: Quaternion
@@ -520,7 +520,7 @@ class Quaternion(BasePoseList):
         :seealso: :func:`__ne__` :func:`~spatialmath.base.quaternions.qisequal`
         """
         assert isinstance(left, type(right)), "operands to == are of different types"
-        return left.binop(right, lambda x, y: not base.qisequal(x, y), list1=False)
+        return left.binop(right, lambda x, y: not smb.qisequal(x, y), list1=False)
 
     def __mul__(
         left, right: Quaternion
@@ -575,9 +575,9 @@ class Quaternion(BasePoseList):
         """
         if isinstance(right, left.__class__):
             # quaternion * [unit]quaternion case
-            return Quaternion(left.binop(right, base.qqmul))
+            return Quaternion(left.binop(right, smb.qqmul))
 
-        elif base.isscalar(right):
+        elif smb.isscalar(right):
             # quaternion * scalar case
             # print('scalar * quat')
             return Quaternion([right * q._A for q in left])
@@ -658,7 +658,7 @@ class Quaternion(BasePoseList):
 
         :seealso: :func:`~spatialmath.base.quaternions.qpow`
         """
-        return self.__class__([base.qpow(q._A, n) for q in self])
+        return self.__class__([smb.qpow(q._A, n) for q in self])
 
     def __ipow__(self, n: int) -> Quaternion:
         """
@@ -892,7 +892,7 @@ class Quaternion(BasePoseList):
             delim = ("<<", ">>")
         else:
             delim = ("<", ">")
-        return "\n".join([base.qprint(q, file=None, delim=delim) for q in self.data])
+        return "\n".join([smb.qprint(q, file=None, delim=delim) for q in self.data])
 
 
 # ========================================================================= #
@@ -981,7 +981,7 @@ class UnitQuaternion(Quaternion):
             # single argument
             if super().arghandler(s, check=check):
                 # create unit quaternion
-                self.data = [base.qunit(q) for q in self.data]
+                self.data = [smb.qunit(q) for q in self.data]
 
             elif isinstance(s, np.ndarray):
                 # passed a NumPy array, it could be:
@@ -989,38 +989,38 @@ class UnitQuaternion(Quaternion):
                 #  a quaternion as a 1D array
                 #  an array of quaternions as an nx4 array
 
-                if base.isrot(s, check=check):
+                if smb.isrot(s, check=check):
                     # UnitQuaternion(R) R is 3x3 rotation matrix
-                    self.data = [base.r2q(s)]
+                    self.data = [smb.r2q(s)]
                 elif s.shape == (4,):
                     # passed a 4-vector
                     if norm:
-                        self.data = [base.qunit(s)]
+                        self.data = [smb.qunit(s)]
                     else:
                         self.data = [s]
                 elif s.ndim == 2 and s.shape[1] == 4:
                     if norm:
-                        self.data = [base.qunit(x) for x in s]
+                        self.data = [smb.qunit(x) for x in s]
                     else:
-                        # self.data = [base.qpositive(x) for x in s]
+                        # self.data = [smb.qpositive(x) for x in s]
                         self.data = [x for x in s]
 
             elif isinstance(s, SO3):
                 # UnitQuaternion(x) x is SO3 or SE3 (since SE3 is subclass of SO3)
-                self.data = [base.r2q(x.R) for x in s]
+                self.data = [smb.r2q(x.R) for x in s]
 
             elif isinstance(s[0], SO3):
                 # list of SO3 or SE3
-                self.data = [base.r2q(x.R) for x in s]
+                self.data = [smb.r2q(x.R) for x in s]
 
             else:
                 raise ValueError("bad argument to UnitQuaternion constructor")
 
-        elif base.isscalar(s) and base.isvector(v, 3):
+        elif smb.isscalar(s) and smb.isvector(v, 3):
             # UnitQuaternion(s, v)   s is scalar, v is 3-vector
-            q = np.r_[s, base.getvector(v)]
+            q = np.r_[s, smb.getvector(v)]
             if norm:
-                q = base.qunit(q)
+                q = smb.qunit(q)
             self.data = [q]
 
         else:
@@ -1028,7 +1028,7 @@ class UnitQuaternion(Quaternion):
 
     @staticmethod
     def _identity():
-        return base.qeye()
+        return smb.qeye()
 
     @staticmethod
     def isvalid(x: ArrayLike, check: Optional[bool] = True) -> bool:
@@ -1051,7 +1051,7 @@ class UnitQuaternion(Quaternion):
             >>> UnitQuaternion.isvalid(np.r_[1, 0, 0, 0])
             >>> UnitQuaternion.isvalid(np.r_[1, 2, 3, 4])
         """
-        return x.shape == (4,) and (not check or base.isunitvec(x))
+        return x.shape == (4,) and (not check or smb.isunitvec(x))
 
     @property
     def R(self) -> SO3Array:
@@ -1081,9 +1081,9 @@ class UnitQuaternion(Quaternion):
             rotation matrix is ``x(:,:,i)``.
         """
         if len(self) > 1:
-            return np.array([base.q2r(q) for q in self.data])
+            return np.array([smb.q2r(q) for q in self.data])
         else:
-            return base.q2r(self._A)
+            return smb.q2r(self._A)
 
     @property
     def vec3(self) -> R3:
@@ -1114,16 +1114,16 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :meth:`UnitQuaternion.Vec3`
         """
-        return base.q2v(self._A)
+        return smb.q2v(self._A)
 
     # -------------------------------------------- constructor variants
     @classmethod
-    def Rx(cls, angle: float, unit: Optional[str] = "rad") -> UnitQuaternion:
+    def Rx(cls, angles: ArrayLike, unit: Optional[str] = "rad") -> UnitQuaternion:
         """
         Construct a UnitQuaternion object representing rotation about the X-axis
 
         :arg θ: rotation angle
-        :type θ: float or array_like
+        :type θ: array_like
         :arg unit: rotation unit 'rad' [default] or 'deg'
         :type unit: str
         :return: unit-quaternion
@@ -1142,18 +1142,18 @@ class UnitQuaternion(Quaternion):
             >>> print(UQ.Rx(0.3))
             >>> print(UQ.Rx([0, 0.3, 0.6]))
         """
-        angles = base.getunit(base.getvector(angle), unit)
+        angles = smb.getunit(angles, unit)
         return cls(
             [np.r_[math.cos(a / 2), math.sin(a / 2), 0, 0] for a in angles], check=False
         )
 
     @classmethod
-    def Ry(cls, angle: float, unit: Optional[str] = "rad") -> UnitQuaternion:
+    def Ry(cls, angles: ArrayLike, unit: Optional[str] = "rad") -> UnitQuaternion:
         """
         Construct a UnitQuaternion object representing rotation about the Y-axis
 
         :arg θ: rotation angle
-        :type θ: float or array_like
+        :type θ: array_like
         :arg unit: rotation unit 'rad' [default] or 'deg'
         :type unit: str
         :return: unit-quaternion
@@ -1172,18 +1172,18 @@ class UnitQuaternion(Quaternion):
             >>> print(UQ.Ry(0.3))
             >>> print(UQ.Ry([0, 0.3, 0.6]))
         """
-        angles = base.getunit(base.getvector(angle), unit)
+        angles = smb.getunit(angles, unit)
         return cls(
             [np.r_[math.cos(a / 2), 0, math.sin(a / 2), 0] for a in angles], check=False
         )
 
     @classmethod
-    def Rz(cls, angle: float, unit: Optional[str] = "rad") -> UnitQuaternion:
+    def Rz(cls, angles: ArrayLike, unit: Optional[str] = "rad") -> UnitQuaternion:
         """
         Construct a UnitQuaternion object representing rotation about the Z-axis
 
         :arg θ: rotation angle
-        :type θ: float or array_like
+        :type θ: array_like
         :arg unit: rotation unit 'rad' [default] or 'deg'
         :type unit: str
         :return: unit-quaternion
@@ -1202,7 +1202,7 @@ class UnitQuaternion(Quaternion):
             >>> print(UQ.Rz(0.3))
             >>> print(UQ.Rz([0, 0.3, 0.6]))
         """
-        angles = base.getunit(base.getvector(angle), unit)
+        angles = smb.getunit(angles, unit)
         return cls(
             [np.r_[math.cos(a / 2), 0, 0, math.sin(a / 2)] for a in angles], check=False
         )
@@ -1231,7 +1231,7 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :meth:`UnitQuaternion.Rand`
         """
-        return cls([base.qrand() for i in range(0, N)], check=False)
+        return cls([smb.qrand() for i in range(0, N)], check=False)
 
     @classmethod
     def Eul(cls, *angles: List[float], unit: Optional[str] = "rad") -> UnitQuaternion:
@@ -1265,7 +1265,7 @@ class UnitQuaternion(Quaternion):
         if len(angles) == 1:
             angles = angles[0]
 
-        return cls(base.r2q(base.eul2r(angles, unit=unit)), check=False)
+        return cls(smb.r2q(smb.eul2r(angles, unit=unit)), check=False)
 
     @classmethod
     def RPY(
@@ -1320,7 +1320,7 @@ class UnitQuaternion(Quaternion):
         if len(angles) == 1:
             angles = angles[0]
 
-        return cls(base.r2q(base.rpy2r(angles, unit=unit, order=order)), check=False)
+        return cls(smb.r2q(smb.rpy2r(angles, unit=unit, order=order)), check=False)
 
     @classmethod
     def OA(cls, o: ArrayLike3, a: ArrayLike3) -> UnitQuaternion:
@@ -1355,7 +1355,7 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :func:`~spatialmath.base.transforms3d.oa2r`
         """
-        return cls(base.r2q(base.oa2r(o, a)), check=False)
+        return cls(smb.r2q(smb.oa2r(o, a)), check=False)
 
     @classmethod
     def AngVec(
@@ -1389,9 +1389,8 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :meth:`UnitQuaternion.angvec` :meth:`UnitQuaternion.exp` :func:`~spatialmath.base.transforms3d.angvec2r`
         """
-        v = base.getvector(v, 3)
-        base.isscalar(theta)
-        theta = base.getunit(theta, unit)
+        v = smb.getvector(v, 3)
+        theta = smb.getunit(theta, unit, dim=0)
         return cls(
             s=math.cos(theta / 2), v=math.sin(theta / 2) * v, norm=False, check=False
         )
@@ -1422,11 +1421,11 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :meth:`SE3.angvec` :func:`~spatialmath.base.transforms3d.angvec2r`
         """
-        assert base.isvector(w, 3), "w must be a 3-vector"
-        w = base.getvector(w)
-        theta = base.norm(w)
+        assert smb.isvector(w, 3), "w must be a 3-vector"
+        w = smb.getvector(w)
+        theta = smb.norm(w)
         s = math.cos(theta / 2)
-        v = math.sin(theta / 2) * base.unitvec(w)
+        v = math.sin(theta / 2) * smb.unitvec(w)
         return cls(s=s, v=v, check=False)
 
     @classmethod
@@ -1458,7 +1457,7 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :meth:`UnitQuaternion.vec3`
         """
-        return cls(base.v2q(vec))
+        return cls(smb.v2q(vec))
 
     def inv(self) -> UnitQuaternion:
         """
@@ -1474,14 +1473,14 @@ class UnitQuaternion(Quaternion):
 
         .. runblock:: pycon
 
-            >>> from spatialmath import UnitQuaternio
+            >>> from spatialmath import UnitQuaternion
             >>> print(UQ.Rx(0.3).inv())
             >>> print(UQ.Rx(0.3).inv() * UQ.Rx(0.3))
             >>> print(UQ.Rx([0.3, 0.6]).inv())
 
         :seealso: :func:`~spatialmath.base.quaternions.qinv`
         """
-        return UnitQuaternion([base.qconj(q._A) for q in self])
+        return UnitQuaternion([smb.qconj(q._A) for q in self])
 
     @staticmethod
     def qvmul(qv1: ArrayLike3, qv2: ArrayLike3) -> R3:
@@ -1513,7 +1512,7 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :meth:`UnitQuaternion.vec3` :meth:`UnitQuaternion.Vec3`
         """
-        return base.vvmul(qv1, qv2)
+        return smb.vvmul(qv1, qv2)
 
     def dot(self, omega: ArrayLike3) -> R4:
         """
@@ -1530,7 +1529,7 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :func:`~spatialmath.base.quaternions.qdot`
         """
-        return base.qdot(self._A, omega)
+        return smb.qdot(self._A, omega)
 
     def dotb(self, omega: ArrayLike3) -> R4:
         """
@@ -1547,7 +1546,7 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :func:`~spatialmath.base.quaternions.qdotb`
         """
-        return base.qdotb(self._A, omega)
+        return smb.qdotb(self._A, omega)
 
     def __mul__(
         left, right: UnitQuaternion
@@ -1607,7 +1606,7 @@ class UnitQuaternion(Quaternion):
             >>> q = UQ.Rx(0.3)
             >>> q *= UQ.Rx(0.4))
             >>> print(q)
-            >>> print(UQ.Rx(0.3) * UQ.Rx([0.4, 0.6])
+            >>> print(UQ.Rx(0.3) * UQ.Rx([0.4, 0.6]))
             >>> print(UQ.Rx([0.3, 0.6]) * UQ.Rx(0.3))
             >>> print(UQ.Rx([0.3, 0.6]) * UQ.Rx([0.3, 0.6]))
 
@@ -1615,9 +1614,9 @@ class UnitQuaternion(Quaternion):
         """
         if isinstance(left, right.__class__):
             # quaternion * quaternion case (same class)
-            return right.__class__(left.binop(right, base.qqmul))
+            return right.__class__(left.binop(right, smb.qqmul))
 
-        elif base.isscalar(right):
+        elif smb.isscalar(right):
             # quaternion * scalar case
             # print('scalar * quat')
             return Quaternion([right * q._A for q in left])
@@ -1625,23 +1624,23 @@ class UnitQuaternion(Quaternion):
         elif isinstance(right, (list, tuple, np.ndarray)):
             # unit quaternion * vector
             # print('*: pose x array')
-            if base.isvector(right, 3):
-                v = base.getvector(right)
+            if smb.isvector(right, 3):
+                v = smb.getvector(right)
                 if len(left) == 1:
                     # pose x vector
                     # print('*: pose x vector')
-                    return base.qvmul(left._A, base.getvector(right, 3))
+                    return smb.qvmul(left._A, smb.getvector(right, 3))
 
-                elif len(left) > 1 and base.isvector(right, 3):
+                elif len(left) > 1 and smb.isvector(right, 3):
                     # pose array x vector
                     # print('*: pose array x vector')
-                    return np.array([base.qvmul(x, v) for x in left._A]).T
+                    return np.array([smb.qvmul(x, v) for x in left._A]).T
 
             elif (
                 len(left) == 1 and isinstance(right, np.ndarray) and right.shape[0] == 3
             ):
                 # pose x stack of vectors
-                return np.array([base.qvmul(left._A, x) for x in right.T]).T
+                return np.array([smb.qvmul(left._A, x) for x in right.T]).T
             else:
                 raise ValueError("bad operands")
         else:
@@ -1728,9 +1727,9 @@ class UnitQuaternion(Quaternion):
         """
         if isinstance(left, right.__class__):
             return UnitQuaternion(
-                left.binop(right, lambda x, y: base.qqmul(x, base.qconj(y)))
+                left.binop(right, lambda x, y: smb.qqmul(x, smb.qconj(y)))
             )
-        elif base.isscalar(right):
+        elif smb.isscalar(right):
             return Quaternion(left.binop(right, lambda x, y: x / y))
         else:
             raise ValueError("bad operands")
@@ -1763,7 +1762,7 @@ class UnitQuaternion(Quaternion):
         :seealso: :func:`__ne__` :func:`~spatialmath.base.quaternions.qisequal`
         """
         return left.binop(
-            right, lambda x, y: base.qisequal(x, y, unitq=True), list1=False
+            right, lambda x, y: smb.qisequal(x, y, unitq=True), list1=False
         )
 
     def __ne__(
@@ -1794,7 +1793,7 @@ class UnitQuaternion(Quaternion):
         :seealso: :func:`__eq__` :func:`~spatialmath.base.quaternions.qisequal`
         """
         return left.binop(
-            right, lambda x, y: not base.qisequal(x, y, unitq=True), list1=False
+            right, lambda x, y: not smb.qisequal(x, y, unitq=True), list1=False
         )
 
     def __matmul__(
@@ -1815,7 +1814,7 @@ class UnitQuaternion(Quaternion):
             over many cycles.
         """
         return left.__class__(
-            left.binop(right, lambda x, y: base.qunit(base.qqmul(x, y)))
+            left.binop(right, lambda x, y: smb.qunit(smb.qqmul(x, y)))
         )
 
     def interp(
@@ -1865,7 +1864,7 @@ class UnitQuaternion(Quaternion):
         if isinstance(s, int) and s > 1:
             s = np.linspace(0, 1, s)
         else:
-            s = base.getvector(s)
+            s = smb.getvector(s)
             s = np.clip(s, 0, 1)  # enforce valid values
 
         # 2 quaternion form
@@ -1873,7 +1872,7 @@ class UnitQuaternion(Quaternion):
             raise TypeError("end argument must be a UnitQuaternion")
         q1 = self.vec
         q2 = end.vec
-        dot = base.qinner(q1, q2)
+        dot = smb.qinner(q1, q2)
 
         # If the dot product is negative, the quaternions
         # have opposite handed-ness and slerp won't take
@@ -1901,7 +1900,7 @@ class UnitQuaternion(Quaternion):
 
     def interp1(self, s: float = 0, shortest: Optional[bool] = False) -> UnitQuaternion:
         """
-        Interpolate a unit quaternions
+        Interpolate a unit quaternion
 
         :param shortest: Take the shortest path along the great circle
         :param s: interpolation coefficient, range 0 to 1, or number of steps
@@ -1927,7 +1926,7 @@ class UnitQuaternion(Quaternion):
             >>> q.interp1(0)    # this is identity
             >>> q.interp1(1)    # this is q
             >>> q.interp1(0.5)  # this is in between
-            >>> qi = q.interp1(q2, 11)  # in 11 steps
+            >>> qi = q.interp1(11)  # in 11 steps
             >>> len(qi)
             >>> qi[0]                # this is q1
             >>> qi[5]                # this is in between
@@ -1941,7 +1940,7 @@ class UnitQuaternion(Quaternion):
         if isinstance(s, int) and s > 1:
             s = np.linspace(0, 1, s)
         else:
-            s = base.getvector(s)
+            s = smb.getvector(s)
             s = np.clip(s, 0, 1)  # enforce valid values
 
         q = self.vec
@@ -1985,7 +1984,7 @@ class UnitQuaternion(Quaternion):
 
         # is (v, theta) or None
         try:
-            v, theta = base.unitvec_norm(w)
+            v, theta = smb.unitvec_norm(w)
         except ValueError:
             # zero update
             return
@@ -1993,9 +1992,9 @@ class UnitQuaternion(Quaternion):
         ds = math.cos(theta / 2)
         dv = math.sin(theta / 2) * v
 
-        updated = base.qqmul(self.A, np.r_[ds, dv])
+        updated = smb.qqmul(self.A, np.r_[ds, dv])
         if normalize:
-            updated = base.qunit(updated)
+            updated = smb.qunit(updated)
         self.data = [updated]
 
     def plot(self, *args: List, **kwargs):
@@ -2014,7 +2013,7 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :func:`~spatialmath.base.transforms3d.trplot`
         """
-        base.trplot(base.q2r(self._A), *args, **kwargs)
+        smb.trplot(smb.q2r(self._A), *args, **kwargs)
 
     def animate(self, *args: List, **kwargs):
         """
@@ -2040,9 +2039,9 @@ class UnitQuaternion(Quaternion):
         :see :func:`~spatialmath.base.transforms3d.tranimate` :func:`~spatialmath.base.transforms3d.trplot`
         """
         if len(self) > 1:
-            base.tranimate([base.q2r(q) for q in self.data], *args, **kwargs)
+            return smb.tranimate([smb.q2r(q) for q in self.data], *args, **kwargs)
         else:
-            base.tranimate(base.q2r(self._A), *args, **kwargs)
+            return smb.tranimate(smb.q2r(self._A), *args, **kwargs)
 
     def rpy(
         self, unit: Optional[str] = "rad", order: Optional[str] = "zyx"
@@ -2087,9 +2086,9 @@ class UnitQuaternion(Quaternion):
         :seealso: :meth:`SE3.RPY` :func:`~spatialmath.base.transforms3d.tr2rpy`
         """
         if len(self) == 1:
-            return base.tr2rpy(self.R, unit=unit, order=order)
+            return smb.tr2rpy(self.R, unit=unit, order=order)
         else:
-            return np.array([base.tr2rpy(q.R, unit=unit, order=order) for q in self])
+            return np.array([smb.tr2rpy(q.R, unit=unit, order=order) for q in self])
 
     def eul(self, unit: Optional[str] = "rad") -> Union[R3, RNx3]:
         r"""
@@ -2123,9 +2122,9 @@ class UnitQuaternion(Quaternion):
         :seealso: :meth:`SE3.Eul` :func:`~spatialmath.base.transforms3d.tr2eul`
         """
         if len(self) == 1:
-            return base.tr2eul(self.R, unit=unit)
+            return smb.tr2eul(self.R, unit=unit)
         else:
-            return np.array([base.tr2eul(q.R, unit=unit) for q in self])
+            return np.array([smb.tr2eul(q.R, unit=unit) for q in self])
 
     def angvec(self, unit: Optional[str] = "rad") -> Tuple[float, R3]:
         r"""
@@ -2151,7 +2150,7 @@ class UnitQuaternion(Quaternion):
 
         :seealso: :meth:`Quaternion.AngVec` :meth:`UnitQuaternion.log` :func:`~spatialmath.base.transforms3d.angvec2r`
         """
-        return base.tr2angvec(self.R, unit=unit)
+        return smb.tr2angvec(self.R, unit=unit)
 
     # def log(self):
     #     r"""
@@ -2177,7 +2176,7 @@ class UnitQuaternion(Quaternion):
 
     #     :seealso: :meth:`Quaternion.Quaternion.log`, `~spatialmath.quaternion.Quaternion.exp`
     #     """
-    #     return Quaternion(s=0, v=math.acos(self.s) * base.unitvec(self.v))
+    #     return Quaternion(s=0, v=math.acos(self.s) * smb.unitvec(self.v))
 
     def angdist(self, other: UnitQuaternion, metric: Optional[int] = 3) -> float:
         r"""
@@ -2240,8 +2239,8 @@ class UnitQuaternion(Quaternion):
         elif metric == 3:
 
             def metric3(p, q):
-                x = base.norm(p - q)
-                y = base.norm(p + q)
+                x = smb.norm(p - q)
+                y = smb.norm(p + q)
                 if x >= y:
                     return 2 * math.atan(y / x)
                 else:
@@ -2295,7 +2294,7 @@ class UnitQuaternion(Quaternion):
             >>> UQ.Rz(0.3).SE3()
 
         """
-        return SE3(base.r2t(self.R), check=False)
+        return SE3(smb.r2t(self.R), check=False)
 
 
 if __name__ == "__main__":  # pragma: no cover
